@@ -64,6 +64,8 @@
 #define kVLCAutomaticallyPlayNextItem @"AutomaticallyPlayNextItem"
 #define kVLCSettingDownloadArtwork @"download-artwork"
 #define kVLCSettingUseSPDIF @"kVLCSettingUseSPDIF"
+#define kVLCSettingBackupMediaLibrary @"BackupMediaLibrary"
+#define kVLCSettingBackupMediaLibraryDefaultValue @NO
 
 #define kVLCSettingLastUsedSubtitlesSearchLanguage @"kVLCSettingLastUsedSubtitlesSearchLanguage"
 #define kVLCSettingWiFiSharingIPv6 @"wifi-sharing-ipv6"
@@ -74,3 +76,5 @@
 #define kVLCStoredServerList @"kVLCStoredServerList"
 
 #define kVLCHTTPUploadDirectory @"Upload"
+
+#define kVLCForceSMBV1 @"smb-force-v1"
