@@ -79,7 +79,9 @@
 
 - (void)authenticationSessionsChanged:(NSNotification *)notification
 {
-    [self.tableView reloadData];
+    dispatch_async(dispatch_get_main_queue(), ^{
+        [self.tableView reloadData];
+    });
 }
 
 - (NSString *)detailText
