@@ -48,7 +48,6 @@ NSString *const VLCPlaybackServicePlaybackPositionUpdated = @"VLCPlaybackService
 
     BOOL _isInFillToScreen;
     NSUInteger _previousAspectRatio;
-    
 
     UIView *_videoOutputViewWrapper;
     UIView *_actualVideoOutputView;
@@ -328,7 +327,6 @@ NSString *const VLCPlaybackServicePlaybackPositionUpdated = @"VLCPlaybackService
 }
 
 #if TARGET_OS_IOS
-
 - (void)restoreAudioAndSubtitleTrack
 {
     VLCMLMedia *media = [_delegate mediaForPlayingMedia:_mediaPlayer.media];
@@ -397,10 +395,12 @@ NSString *const VLCPlaybackServicePlaybackPositionUpdated = @"VLCPlaybackService
 
 - (BOOL)currentMediaHasTrackToChooseFrom
 {
-    return [[_mediaPlayer audioTrackIndexes] count] > 2 || [[_mediaPlayer videoSubTitlesIndexes] count] > 1;
+    /* allow track selection if there is more than 1 audio track or if there is video because even if
+     * there is only video, there will always be the option to download additional subtitles */
+    return [[_mediaPlayer audioTrackIndexes] count] > 2 || [[_mediaPlayer videoTrackIndexes] count] >= 1;
 }
 
-- (BOOL) isSeekable
+- (BOOL)isSeekable
 {
     return _mediaPlayer.isSeekable;
 }
@@ -546,7 +546,7 @@ NSString *const VLCPlaybackServicePlaybackPositionUpdated = @"VLCPlaybackService
 
 - (NSInteger)numberOfVideoSubtitlesIndexes
 {
-    return _mediaPlayer.videoSubTitlesIndexes.count;
+    return _mediaPlayer.videoSubTitlesIndexes.count + 1;
 }
 
 - (NSInteger)numberOfTitles
@@ -561,8 +561,12 @@ NSString *const VLCPlaybackServicePlaybackPositionUpdated = @"VLCPlaybackService
 
 - (NSString *)videoSubtitleNameAtIndex:(NSInteger)index
 {
-    if (index >= 0 && index < _mediaPlayer.videoSubTitlesNames.count)
+    NSInteger count = _mediaPlayer.videoSubTitlesNames.count;
+    if (index >= 0 && index < count) {
         return _mediaPlayer.videoSubTitlesNames[index];
+    } else if (index == count) {
+        return NSLocalizedString(@"DOWNLOAD_SUBS_FROM_OSO", nil);
+    }
     return nil;
 }
 
@@ -760,6 +764,8 @@ NSString *const VLCPlaybackServicePlaybackPositionUpdated = @"VLCPlaybackService
         // Normal playback
         if (currentIndex + 1 < mediaListCount) {
             nextIndex =  currentIndex + 1;
+        } else if (self.repeatMode == VLCRepeatAllItems) {
+            nextIndex = 0;
         } else if ([self repeatMode] == VLCDoNotRepeat) {
             nextIndex = -1;
         }
@@ -767,12 +773,12 @@ NSString *const VLCPlaybackServicePlaybackPositionUpdated = @"VLCPlaybackService
     return nextIndex;
 }
 
-- (void)next
+- (BOOL)next
 {
     if (_mediaList.count == 1) {
         NSNumber *skipLength = [[NSUserDefaults standardUserDefaults] valueForKey:kVLCSettingPlaybackForwardSkipLength];
         [_mediaPlayer jumpForward:skipLength.intValue];
-        return;
+        return YES;
     }
 
     NSInteger nextIndex = [self nextMediaIndex];
@@ -783,14 +789,15 @@ NSString *const VLCPlaybackServicePlaybackPositionUpdated = @"VLCPlaybackService
             [[NSNotificationCenter defaultCenter]
              postNotificationName:VLCPlaybackServicePlaybackMetadataDidChange object:self];
         }
-        return;
+        return NO;
     }
 
     [_listPlayer playItemAtNumber:@(nextIndex)];
     [[NSNotificationCenter defaultCenter] postNotificationName:VLCPlaybackServicePlaybackMetadataDidChange object:self];
+    return YES;
 }
 
-- (void)previous
+- (BOOL)previous
 {
     if (_mediaList.count > 1) {
         [_listPlayer previous];
@@ -800,6 +807,7 @@ NSString *const VLCPlaybackServicePlaybackPositionUpdated = @"VLCPlaybackService
         NSNumber *skipLength = [[NSUserDefaults standardUserDefaults] valueForKey:kVLCSettingPlaybackBackwardSkipLength];
         [_mediaPlayer jumpBackward:skipLength.intValue];
     }
+    return YES;
 }
 
 
@@ -1278,20 +1286,17 @@ NSString *const VLCPlaybackServicePlaybackPositionUpdated = @"VLCPlaybackService
 
 - (void)remoteControlServiceHitStop:(VLCRemoteControlService *)rcs
 {
-    //TODO handle stop playback entirely
-    [_listPlayer stop];
+    [self stopPlayback];
 }
 
 - (BOOL)remoteControlServiceHitPlayNextIfPossible:(VLCRemoteControlService *)rcs
 {
-    //TODO This doesn't handle shuffle or repeat yet
-    return [_listPlayer next];
+    return [self next];
 }
 
 - (BOOL)remoteControlServiceHitPlayPreviousIfPossible:(VLCRemoteControlService *)rcs
 {
-    //TODO This doesn't handle shuffle or repeat yet
-    return [_listPlayer previous];
+    return [self previous];
 }
 
 - (void)remoteControlService:(VLCRemoteControlService *)rcs jumpForwardInSeconds:(NSTimeInterval)seconds
@@ -1335,13 +1340,13 @@ NSString *const VLCPlaybackServicePlaybackPositionUpdated = @"VLCPlaybackService
 }
 
 #pragma mark - Renderer
+
 - (void)setRenderer:(VLCRendererItem * __nullable)renderer
 {
     _renderer = renderer;
     [_mediaPlayer setRendererItem:_renderer];
 }
 
-
 #pragma mark - PlayerDisplayController
 
 - (void)setPlayerDisplayController:(VLCPlayerDisplayController *)playerDisplayController
